@@ -6,19 +6,19 @@ use warnings;
 use Carp  qw(croak);
 use DateTime;
 
-our $VERSION = "0.5";
+our $VERSION = "0.6";
 
 my @members = qw(
-    KinoshitaHiyori
     MatobaKarin
     NagataMinari
     NakamuraAkari
     NemotoNagi
-    NishiNanami
     OkumuraNonoka
     ShigematsuYuka
     SuyamaEmiri
     TsurumiMoe
+    OtsukaMiyu
+    YamatoAo
 );
 
 sub new {
